@@ -18,7 +18,7 @@ BEGIN {
 
 use Exporter ();
 use vars qw($VERSION @ISA @EXPORT @EXPORT_OK);
-$VERSION   = '2.18_001';
+$VERSION   = '2.13';
 $VERSION   = eval $VERSION;
 @ISA       = qw(Exporter);
 @EXPORT    = qw(mkpath rmtree);
@@ -633,7 +633,7 @@ File::Path - Create or remove directory trees
 
 =head1 VERSION
 
-2.18_001 - released November 4 2020.
+2.13 - released May 31 2017.
 
 =head1 SYNOPSIS
 
@@ -774,14 +774,12 @@ identical to C<make_path()>.
 
 The C<remove_tree> function deletes the given directories and any
 files and subdirectories they might contain, much like the Unix
-command C<rm -rf> or the Windows commands C<rmdir /s> and C<rd /s>.
+command C<rm -rf> or the Windows commands C<rmdir /s> and C<rd /s>. The
+only exception to the function similarity is that C<remove_tree> accepts
+only directories whereas C<rm -rf> also accepts files.
 
-The function accepts a list of directories to be removed. (In point of fact,
-it will also accept filesystem entries which are not directories, such as
-regular files and symlinks.  But, as its name suggests, its intent is to
-remove trees rather than individual files.)
-
-C<remove_tree()>'s behaviour may be tuned by an optional hashref
+The function accepts a list of directories to be
+removed. Its behaviour may be tuned by an optional hashref
 appearing as the last parameter on the call.  If an empty string is
 passed to C<remove_tree>, an error will occur.
 
@@ -1246,7 +1244,7 @@ James (Jim) Keenan <F<jkeenan@cpan.org>>.
 
 =head1 CONTRIBUTORS
 
-Contributors to File::Path, in alphabetical order by first name.
+Contributors to File::Path, in alphabetical order.
 
 =over 1
 
@@ -1260,8 +1258,6 @@ Contributors to File::Path, in alphabetical order by first name.
 
 =item John Lightsey <F<john@perlsec.org>>
 
-=item Nigel Horne <F<njh@bandsman.co.uk>>
-
 =item Richard Elberger <F<riche@cpan.org>>
 
 =item Ryan Yee <F<ryee@cpan.org>>
@@ -1277,7 +1273,7 @@ Contributors to File::Path, in alphabetical order by first name.
 =head1 COPYRIGHT
 
 This module is copyright (C) Charles Bailey, Tim Bunce, David Landgren,
-James Keenan and Richard Elberger 1995-2020. All rights reserved.
+James Keenan and Richard Elberger 1995-2017. All rights reserved.
 
 =head1 LICENSE
 
